# PETSc Code of Conduct

The PETSc community follows the [NumFOCUS Code of Conduct](https://numfocus.org/code-of-conduct) including its [reporting system](https://numfocus.typeform.com/to/ynjGdT?typeform-source=numfocus.org).

